@@ -18,14 +18,15 @@ class CustomRetry(Retry):
 
 class HttpClient:
 
-    def __init__(self, log: logging.Logger, proxies: Optional[dict] = None):
+    def __init__(self, log: logging.Logger, proxies: Optional[dict] = None, http_timeout: int = REQUEST_TIMEOUT):
         self._log = log
         self._proxies = proxies
         self._session = requests.Session()
+        self.http_timeout = http_timeout
         self._session.mount('https://', HTTPAdapter(max_retries=CustomRetry(
             total=3,
             backoff_factor=0.5,
-            status_forcelist=[400, 401, 403, 404, 413, 429, 500, 502, 503, 504],
+            status_forcelist=[429, 500, 502, 503, 504],
             method_whitelist=["TRACE", "PUT", "DELETE", "OPTIONS", "HEAD", "GET", "POST"],
             raise_on_status=False,
         )))
@@ -43,7 +44,7 @@ class HttpClient:
                                       json=body,
                                       params=parameters,
                                       headers=headers,
-                                      timeout=REQUEST_TIMEOUT,
+                                      timeout=self.http_timeout,
                                       proxies=self._proxies,
                                       verify=False)
             self._log.debug(f"Received response {method} {url} {parameters if parameters else ''}: {r}")
